.. image:: https://img.shields.io/travis/eikendev/dudendas/master
   :alt: Build status
   :target: https://travis-ci.org/github/eikendev/dudendas/builds/

.. image:: https://img.shields.io/pypi/status/dudendas
   :alt: Development status
   :target: https://pypi.org/project/dudendas/

.. image:: https://img.shields.io/pypi/l/dudendas
   :alt: License
   :target: https://pypi.org/project/dudendas/

.. image:: https://img.shields.io/pypi/pyversions/dudendas
   :alt: Python version
   :target: https://pypi.org/project/dudendas/

.. image:: https://img.shields.io/pypi/v/dudendas
   :alt: Version
   :target: https://pypi.org/project/dudendas/

.. image:: https://img.shields.io/pypi/dm/dudendas
   :alt: Downloads
   :target: https://pypi.org/project/dudendas/

Usage
=====

A tool for collecting words from Duden.

Installation
============

From PyPI
---------
::

   pip install dudendas

From Source
-----------
::

   ./setup.py install

Development
===========

The source code is located on `GitHub <https://github.com/eikendev/dudendas>`_.
To check out the repository, the following command can be used.
::

   git clone https://github.com/eikendev/dudendas.git
